@@ -64,6 +64,7 @@ PASSWORD_PARAMETER_NAMES = (
     'AdminToken',
     'AodhPassword',
     'BarbicanPassword',
+    'BarbicanSimpleCryptoKek',
     'CeilometerMeteringSecret',
     'CeilometerPassword',
     'CephAdminKey',
@@ -75,6 +76,7 @@ PASSWORD_PARAMETER_NAMES = (
     'CephRgwKey',
     'CinderPassword',
     'CongressPassword',
+    'DesignatePassword',
     'Ec2ApiPassword',
     'EtcdInitialClusterToken',
     'GlancePassword',
@@ -114,10 +116,6 @@ PASSWORD_PARAMETER_NAMES = (
 
 PLAN_NAME_PATTERN = '^[a-zA-Z0-9-]+$'
 
-# The default version of the Bare metal API to set in overcloudrc.
-# 1.34 is the latest API version in Ironic Pike supported by ironicclient.
-DEFAULT_BAREMETAL_API_VERSION = '1.34'
-
 # The default version of the Image API to set in overcloudrc.
 DEFAULT_IMAGE_API_VERSION = '2'
 
@@ -148,10 +146,9 @@ LEGACY_API_NETWORK = 'Internal'
 # Default nested depth when recursing Heat stacks
 NESTED_DEPTH = 7
 
-# Default string format for server resource types
-SERVER_RESOURCE_TYPES = 'OS::TripleO::%sServer'
-
 # Resource name for deployment resources when using config download
 TRIPLEO_DEPLOYMENT_RESOURCE = 'TripleODeployment'
 
+HOST_NETWORK = 'ctlplane'
+
 EXTERNAL_TASKS = ['external_deploy_tasks']
