@@ -26,6 +26,7 @@ from tripleo_common.utils import passwords as password_utils
 _EXISTING_PASSWORDS = {
     'MistralPassword': 'VFJeqBKbatYhQm9jja67hufft',
     'BarbicanPassword': 'MGGQBtgKT7FnywvkcdMwE9nhx',
+    'BarbicanSimpleCryptoKek': 'dGhpcnR5X3R3b19ieXRlX2tleWJsYWhibGFoYmxhaGg=',
     'AdminPassword': 'jFmY8FTpvtF2e4d4ReXvmUP8k',
     'CeilometerMeteringSecret': 'CbHTGK4md4Cc8P8ZyzTns6wry',
     'ZaqarPassword': 'bbFgCTFbAH8vf9n3xvZCP8aMR',
@@ -63,6 +64,7 @@ _EXISTING_PASSWORDS = {
     'MysqlClustercheckPassword': 'jN4RMMWWJ4sycaRwh7UvrAtfX',
     'CephClientKey': b'AQCQXtlXAAAAABAAKyc+8St8i9onHyu2mPk+vg==',
     'NeutronPassword': 'ZxAjdU2UXCV4GM3WyPKrzAZXD',
+    'DesignatePassword': 'wHYj7rftFzHMpJKnGxbjjR9CW',
     'KeystoneCredential0': 'ftJNQ_XlDUK7Lgvv1kdWf3SyqVsrvNDgoNV4kJg3yzw=',
     'KeystoneCredential1': 'c4MFq82TQLFLKpiiUjrKkp15dafE2ALcD3jbaIu3rfE=',
     'KeystoneFernetKey0': 'O8NSPxr4zXBBAoGIj-5aUmtE7-Jk5a4ptVsEhzJ8Vd8=',
