@@ -50,7 +50,7 @@ class TestImageUploadManager(base.TestCase):
     @mock.patch('os.path.isfile', return_value=True)
     @mock.patch('fcntl.ioctl', side_effect=Exception)
     @mock.patch('tripleo_common.image.image_uploader.Client')
-    def test_file_parsing(self, mockpath, mockioctl, mockdocker):
+    def test_file_parsing(self, mockdocker, mockioctl, mockpath):
         print(filedata)
         manager = ImageUploadManager(self.filelist, debug=True)
         parsed_data = manager.upload()
@@ -63,6 +63,27 @@ class TestImageUploadManager(base.TestCase):
                                     key=operator.itemgetter('imagename'))
         self.assertEqual(sorted_expected_data, sorted_parsed_data)
 
+        dockerc = mockdocker.return_value
+        dockerc.remove_image.assert_has_calls([
+            mock.call('docker.io/tripleoupstream'
+                      '/centos-binary-nova-compute:liberty'),
+            mock.call('docker.io/tripleoupstream'
+                      '/centos-binary-nova-libvirt:liberty'),
+            mock.call('docker.io/tripleoupstream'
+                      '/heat-docker-agents-centos:latest'),
+            mock.call('docker.io/tripleoupstream'
+                      '/image-with-missing-tag:latest'),
+
+            mock.call('localhost:8787/tripleoupstream'
+                      '/centos-binary-nova-compute:liberty'),
+            mock.call('localhost:8787/tripleoupstream'
+                      '/centos-binary-nova-libvirt:liberty'),
+            mock.call('localhost:8787/tripleoupstream'
+                      '/heat-docker-agents-centos:latest'),
+            mock.call('localhost:8787/tripleoupstream/'
+                      'image-with-missing-tag:latest'),
+        ])
+
 
 class TestImageUploader(base.TestCase):
 
