@@ -111,9 +111,7 @@ class TestConfig(base.TestCase):
             KeyError,
             self.config.download_config, *args)
 
-    @mock.patch('tripleo_common.utils.config.Config.get_role_data',
-                autospec=True)
-    def test_overcloud_config_upgrade_tasks(self, mock_get_role_data):
+    def test_overcloud_config_upgrade_tasks(self):
 
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
@@ -140,8 +138,6 @@ class TestConfig(base.TestCase):
                                            'tags': 'step1',
                                            'when': ['step|int == 1',
                                                     'existing', 'list']}]}
-        mock_get_role_data.return_value = fake_role
-
         for role in fake_role:
             filedir = os.path.join(self.tmp_dir, role)
             os.makedirs(filedir)
@@ -152,34 +148,25 @@ class TestConfig(base.TestCase):
             self.assertTrue(os.path.isfile(filepath))
             self.assertEqual(expected_tasks[role], playbook_tasks)
 
-    def test_get_server_data(self):
+    def test_get_server_names(self):
         heat = mock.MagicMock()
         self.config = ooo_config.Config(heat)
-        stack = 'overcloud'
-        role_names = ['Controller', 'Compute', 'Custom']
-        heat.resources.list.return_value = ['fakeserver']
-        server_data = self.config.get_server_data(stack, role_names)
-        self.assertEqual(heat.resources.list.call_count, 3)
-        self.assertEqual(
-            heat.resources.list.call_args_list[0],
-            mock.call(stack,
-                      filters=dict(type='OS::TripleO::ControllerServer'),
-                      nested_depth=constants.NESTED_DEPTH,
-                      with_detail=True))
-        self.assertEqual(
-            heat.resources.list.call_args_list[1],
-            mock.call(stack,
-                      filters=dict(type='OS::TripleO::ComputeServer'),
-                      nested_depth=constants.NESTED_DEPTH,
-                      with_detail=True))
-        self.assertEqual(
-            heat.resources.list.call_args_list[2],
-            mock.call(stack,
-                      filters=dict(type='OS::TripleO::CustomServer'),
-                      nested_depth=constants.NESTED_DEPTH,
-                      with_detail=True))
-        self.assertEqual(server_data,
-                         ['fakeserver', 'fakeserver', 'fakeserver'])
+        self.config.stack_outputs = {
+            'RoleNetHostnameMap': {
+                'Controller': {
+                    'ctlplane': [
+                        'c0.ctlplane.localdomain',
+                        'c1.ctlplane.localdomain',
+                        'c2.ctlplane.localdomain']}},
+            'ServerIdData': {
+                'server_ids': {
+                    'Controller': [
+                        '8269f736',
+                        '2af0a373',
+                        'c8479674']}}}
+        server_names = self.config.get_server_names()
+        expected = {'2af0a373': 'c1', '8269f736': 'c0', 'c8479674': 'c2'}
+        self.assertEqual(expected, server_names)
 
     def test_get_deployment_data(self):
         heat = mock.MagicMock()
@@ -212,17 +199,8 @@ class TestConfig(base.TestCase):
             'data',
             datafile)
         config_data = yaml.safe_load(open(config_data_path).read())
-        server_data = []
         deployment_data = []
 
-        for server in config_data['servers']:
-            server_mock = mock.MagicMock()
-            server_mock.physical_resource_id = server['physical_resource_id']
-            server_mock.name = server['name']
-            server_mock.attributes = {'OS::stack_id': server['OS::stack_id'],
-                                      'name': server['name']}
-            server_data.append(server_mock)
-
         for deployment in config_data['deployments']:
             deployment_mock = mock.MagicMock()
             deployment_mock.id = deployment['deployment']
@@ -233,10 +211,9 @@ class TestConfig(base.TestCase):
                            name=deployment['name']))
             deployment_data.append(deployment_mock)
 
-        server_id_data = config_data['server_id_data']
         configs = config_data['configs']
 
-        return server_data, server_id_data, deployment_data, configs
+        return deployment_data, configs
 
     def _get_config_dict(self, deployment):
         config = self.configs[deployment.attributes['value']['config']].copy()
@@ -254,26 +231,42 @@ class TestConfig(base.TestCase):
         return yaml.safe_load(open(file_path).read())
 
     @patch('tripleo_common.utils.config.Config.get_config_dict')
-    @patch('tripleo_common.utils.config.Config.get_server_id_data')
     @patch('tripleo_common.utils.config.Config.get_deployment_data')
-    @patch('tripleo_common.utils.config.Config.get_server_data')
-    def test_config_download(self, mock_server_data, mock_deployment_data,
-                             mock_server_id_data, mock_config_dict):
+    def test_config_download(self, mock_deployment_data, mock_config_dict):
         heat = mock.MagicMock()
         self.config = ooo_config.Config(heat)
-        stack = 'overcloud'
+        stack = mock.MagicMock()
+        heat.stacks.get.return_value = stack
 
-        server_data, server_id_data, deployment_data, configs = \
+        stack.outputs = [
+            {'output_key': 'RoleNetHostnameMap',
+             'output_value': {
+                 'Controller': {
+                     'ctlplane': [
+                         'overcloud-controller-0.ctlplane.localdomain']},
+                 'Compute': {
+                     'ctlplane': [
+                         'overcloud-novacompute-0.ctlplane.localdomain',
+                         'overcloud-novacompute-1.ctlplane.localdomain',
+                         'overcloud-novacompute-2.ctlplane.localdomain']}}},
+            {'output_key': 'ServerIdData',
+             'output_value': {
+                 'server_ids': {
+                     'Controller': [
+                         '00b3a5e1-5e8e-4b55-878b-2fa2271f15ad'],
+                     'Compute': [
+                         'a7db3010-a51f-4ae0-a791-2364d629d20d',
+                         '8b07cd31-3083-4b88-a433-955f72039e2c',
+                         '169b46f8-1965-4d90-a7de-f36fb4a830fe']}}}]
+        deployment_data, configs = \
             self._get_config_data('config_data.yaml')
         self.configs = configs
 
-        mock_server_data.return_value = server_data
-        mock_server_id_data.return_value = server_id_data
         mock_deployment_data.return_value = deployment_data
         mock_config_dict.side_effect = self._get_config_dict
 
-        tmp_path = self.config.download_config(stack, '/tmp')
-        print("config at %s" % tmp_path)
+        self.tmp_dir = self.useFixture(fixtures.TempDir()).path
+        tmp_path = self.config.download_config(stack, self.tmp_dir)
 
         for f in ['overcloud-controller-0',
                   'overcloud-novacompute-0',
